GC.fun: GC content calculator

Description Usage Arguments Author(s)

View source: R/fragCounter.R

Description

Calculates GC content across the genome for a given sized window

Usage

1
2
GC.fun(win.size = 200, twobitURL = "~/DB/UCSC/hg19.2bit",
  twobit.win = 1000, mc.cores = 1, exome = FALSE)

Arguments

win.size

integer Window size, in basepairs, to calculate GC content for (should match window size of your coverage file

twobitURL

string URL to twobit genome file. Default is hg19 from UCSC

twobit.win

integer How many windows of the twobit file to load into memory on each core

mc.cores

integer How many cores to use

exome

boolean If TRUE, calculate mappability for exons instead of window

Author(s)

Trent Walradt


kcygan/fragCounter documentation built on Feb. 13, 2020, 12:34 a.m.