Description Usage Arguments Author(s)
Calculates mappability as fraction of bases in a tile with mappability of 1
1 2 3 |
win.size |
integer Window size, in basepairs, to calculate mappability for (should match window size of your coverage file |
twobitURL |
string URL to twobit genome file. Default is hg19 from UCSC |
bw.path |
string Path to .bigWig mappability file |
twobit.win |
integer How many windows of the twobit file to load into memory on each core |
mc.cores |
integer How many cores to use |
exome |
boolean If TRUE, calculate mappability for exons instead of window |
Trent Walradt
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.