correctcov_stub: Correct coverage stub

Description Usage Arguments Author(s)

View source: R/fragCounter.R

Description

prepares GC, mappability, and coverage files for multicoco

Usage

1
2
correctcov_stub(cov.wig, mappability = 0.9, samplesize = 50000,
  verbose = T, gc.rds.dir, map.rds.dir, exome = FALSE)

Arguments

cov.wig

wig file of coverage tiles of width W or pointer to rds file of sorted GRanges object or GRanges object

mappability

double threshold for mappability score

samplesize

integer size of sub-sample

verbose

boolean Wether to print log to console

gc.rds.dir

string for tiles of width W, will look here for a file named gcW.rds in this directory

map.rds.dir

string for tiles of width W will look here for a file named mapW.rds in this directory

exome

boolean If TRUE, look in gc/map.rds.dir for files called 'gcexome.rds' and 'mapexome.rds'

Author(s)

Trent Walradt


kcygan/fragCounter documentation built on Feb. 13, 2020, 12:34 a.m.