fragCounter: fragCounter

Description Usage Arguments Author(s)

View source: R/fragCounter.R

Description

Runs entire fragCounter pipeline

Usage

1
2
3
fragCounter(bam, skeleton, cov = NULL, midpoint = TRUE, window = 200,
  gc.rds.dir, map.rds.dir, minmapq = 1, paired = TRUE, outdir = NULL,
  exome = FALSE, use.skel = FALSE)

Arguments

bam

string path to .bam file

skeleton

string Input data.table with intervals for which there is coverage data

cov

string path to existing coverage rds or bedgraph

midpoint

boolean If TRUE only count midpoint if FALSE then count bin footprint of every fragment interval

window

integer window / bin size

gc.rds.dir

string for tiles of width W, will look here for a file named gcW.rds in this directory

map.rds.dir

string for tiles of width W will look here for a file named mapW.rds in this directory

minmapq

double Minimal map quality

paired

boolean wether or not paired

outdir

string Directory to dump output into

exome

boolean If TRUE, perform correction using exons as bins instead of fixed size

use.skel

boolean flag If false then default exome skeleton from gencode is used, if TRUE, user defined skeleton is used

Author(s)

Marcin Imielinski


kcygan/fragCounter documentation built on Feb. 13, 2020, 12:34 a.m.