make.blacklist: Make a list of regions of the genome in which there is...

Description Usage Arguments Value Author(s)

View source: R/fragCounter.R

Description

Look at all available normal samples and find regions where some percentage of all normal samples have at least 1 read

Usage

1
make.blacklist(pairs, cutoff = 0.9, mc.cores = mc.cores)

Arguments

pairs

string Input data.table with columns 'pair' and 'bam' corresponding to the sample name and bath to normal bam

cutoff

double Threshold for what percentage of normal samples must have reads for the region to be included

Value

Data.table of regions to include when calculating corrected reads

Author(s)

Trent Walradt


kcygan/fragCounter documentation built on Feb. 13, 2020, 12:34 a.m.