multicoco: Multi-scale coverage correction

Description Usage Arguments Author(s)

View source: R/fragCounter.R

Description

Given gc and mappability coverage correction at k "nested" scales finds the coverage assignment at the finest scale that yields the best correction at every scale

Usage

1
2
3
4
multicoco(cov, numlevs = 1, base = max(10, 1e5/max(width(cov))),
fields = c("gc", "map"), iterative = TRUE, presegment = TRUE,
min.segwidth = 5e6, mono = TRUE, verbose = TRUE, FUN = NULL, ...,
mc.cores = 1, exome = FALSE)

Arguments

cov

GRanges constant with GRanges of coverage samples with (by default) fields $reads, $map, $gc

numlevs

integer numbers of scales at which to correct

base

integer Scale multiplier

fields

character vector fields of gc to use as covariates

iterative

boolean whether to iterate

presegment

boolean whether to presegment

min.segwidth

integer when presegmenting, minimum segment width

mono

boolean Wether to only do single iteration at finest scale

verbose

boolean Wether to print log to console

FUN

function with which to correct coverage (by default loess correction modified from HMMcopy that takes in granges with fields $reads and other fields specified in "fields"

...

additional args to FUN

mc.cores

integer Number of cores to use

exome

boolean If TRUE, perform correction using exons as bins instead of fixed size

Author(s)

Marcin Imielinski


kcygan/fragCounter documentation built on Feb. 13, 2020, 12:34 a.m.