Description Usage Arguments Author(s)
prepares GC, mappability, and coverage files for multicoco
1 2 | correctcov_stub(cov.wig, mappability = 0.9, samplesize = 50000,
verbose = T, gc.rds.dir, map.rds.dir, exome = FALSE)
|
cov.wig |
wig file of coverage tiles of width W or pointer to rds file of sorted GRanges object or GRanges object |
mappability |
double threshold for mappability score |
samplesize |
integer size of sub-sample |
verbose |
boolean Wether to print log to console |
gc.rds.dir |
string for tiles of width W, will look here for a file named gcW.rds in this directory |
map.rds.dir |
string for tiles of width W will look here for a file named mapW.rds in this directory |
exome |
boolean If TRUE, look in gc/map.rds.dir for files called 'gcexome.rds' and 'mapexome.rds' |
Trent Walradt
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.