Description Usage Arguments Author(s)
Runs entire fragCounter pipeline
1 2 3 |
bam |
string path to .bam file |
skeleton |
string Input data.table with intervals for which there is coverage data |
cov |
string path to existing coverage rds or bedgraph |
midpoint |
boolean If TRUE only count midpoint if FALSE then count bin footprint of every fragment interval |
window |
integer window / bin size |
gc.rds.dir |
string for tiles of width W, will look here for a file named gcW.rds in this directory |
map.rds.dir |
string for tiles of width W will look here for a file named mapW.rds in this directory |
minmapq |
double Minimal map quality |
paired |
boolean wether or not paired |
outdir |
string Directory to dump output into |
exome |
boolean If TRUE, perform correction using exons as bins instead of fixed size |
use.skel |
boolean flag If false then default exome skeleton from gencode is used, if TRUE, user defined skeleton is used |
Marcin Imielinski
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.