Description Usage Arguments Value Author(s)
Look at all available normal samples and find regions where some percentage of all normal samples have at least 1 read
1 | make.blacklist(pairs, cutoff = 0.9, mc.cores = mc.cores)
|
pairs |
string Input data.table with columns 'pair' and 'bam' corresponding to the sample name and bath to normal bam |
cutoff |
double Threshold for what percentage of normal samples must have reads for the region to be included |
Data.table of regions to include when calculating corrected reads
Trent Walradt
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.